# mixprop


[![image](https://img.shields.io/pypi/v/mixprop.svg)](https://pypi.python.org/pypi/mixprop)
[![image](https://img.shields.io/conda/vn/conda-forge/mixprop.svg)](https://anaconda.org/conda-forge/mixprop)


**Viscosity prediction for binary liquid mixtures**


-   Free software: MIT license
-   Documentation: https://cbilodeau2.github.io/mixprop
    

## Features

-   TODO
